import requests

class server:
    def __init__(self, url:str, text:bool=True, plain:bool=False):
        self.url = url
        self.text = text
        self.plain = plain

    def total_memory(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            if self.text == True and self.plain == False:
                total_memory = f"{round(int(data['MemTotal'])/1e+6, 2)} GB"
                return total_memory
            elif self.text == True and self.plain == True:
                total_memory = f"{data['MemTotal']} KB"
                return total_memory
            elif self.text == False and self.plain == True:
                total_memory = float(round(int(data['MemTotal'])/1e+6, 2))
                return total_memory
            elif self.text == False and self.plain == False:
                total_memory = int(data['MemTotal'])
                return total_memory
            else:
                raise Exception("text or plain type is not supported.")

            # total_memory = float(round(int(data['MemTotal'])/1e+6, 2))
        except Exception as e:
            return {"error": e, "data": "-"}

    def free_memory(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            total_memory = float(round(int(data['MemFree'])/1e+6, 2))
            return total_memory
        except:
            return "-"

    def available_memory(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            total_memory = float(round(int(data['MemAvailable'])/1e+6, 2))
            return total_memory
        except:
            return "-"

    def cached_memory(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            total_memory = float(round(int(data['Cached'])/1e+6, 2))
            return total_memory
        except:
            return "-"

    def active_memory(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            total_memory = float(round(int(data['Active'])/1e+6, 2))
            return total_memory
        except:
            return "-"

    def inactive_memory(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            total_memory = float(round(int(data['Inactive'])/1e+6, 2))
            return total_memory
        except:
            return "-"

    def swap_total(self):
        try:
            response = requests.get(self.url + "meminfo")
            data = response.json()['data']
            total_memory = float(round(int(data['SwapTotal'])/1e+6, 2))
            return total_memory
        except:
            return "-"



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python'
]

setup(name='fatcat',
      author='INfoUpgraders',
      url='https://github.com/INfoUpgraders/fatcat',
      project_urls={
        "Documentation": "https://fatcat.readthedocs.io/en/latest/",
        "Issue tracker": "https://github.com/INfoUpgraders/fatcat/issues",
      },
      version='0.0.6.1',
      packages=find_packages(),
      license='MIT',
      description='A python package for FatCat Hosting',
      long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
      long_description_content_type="text/markdown",
      include_package_data=True,
      install_requires=['requests>=2.21.0'],
      extras_require={'docs': ['sphinx==1.8.5', 'sphinxcontrib_trio==1.1.1', 'sphinxcontrib-websupport']},
      python_requires='>=3.6',
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
      ]
)